@@ -1,6 +1,7 @@
 import enum
 import logging
 
+from .. import tracer
 from ..wire.exceptions import PacketInvalidData
 from ..wire.read import (
     read_bytes,
@@ -94,6 +95,7 @@ class CoordinatorProtocol(TCPProtocol):
     PACKET_END = PacketCoordinatorType.PACKET_COORDINATOR_END
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_SERVER_REGISTER(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -128,6 +130,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_SERVER_UPDATE(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -240,6 +243,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_CLIENT_LISTING(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -268,6 +272,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_CLIENT_CONNECT(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -285,6 +290,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_SERCLI_CONNECT_FAILED(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -304,6 +310,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_CLIENT_CONNECTED(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -321,6 +328,7 @@ class CoordinatorProtocol(TCPProtocol):
         }
 
     @staticmethod
+    @tracer.traced("coordinator")
     def receive_PACKET_COORDINATOR_SERCLI_STUN_RESULT(source, data):
         protocol_version, data = read_uint8(data)
 
@@ -341,6 +349,7 @@ class CoordinatorProtocol(TCPProtocol):
             "result": result,
         }
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_ERROR(self, protocol_version, error_no, error_detail):
         data = write_init(PacketCoordinatorType.PACKET_COORDINATOR_GC_ERROR)
 
@@ -358,6 +367,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_REGISTER_ACK(
         self, protocol_version, connection_type, invite_code, invite_code_secret
     ):
@@ -396,6 +406,7 @@ class CoordinatorProtocol(TCPProtocol):
         if count != 0:
             yield count, data
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_NEWGRF_LOOKUP(
         self, protocol_version, newgrf_lookup_table_cursor, newgrf_lookup_table
     ):
@@ -413,6 +424,7 @@ class CoordinatorProtocol(TCPProtocol):
             write_presend(data, SEND_TCP_MTU)
             await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_LISTING(
         self, protocol_version, game_info_version, servers, newgrf_lookup_table
     ):
@@ -491,6 +503,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_CONNECTING(self, protocol_version, token, invite_code):
         data = write_init(PacketCoordinatorType.PACKET_COORDINATOR_GC_CONNECTING)
 
@@ -500,6 +513,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_CONNECT_FAILED(self, protocol_version, token):
         data = write_init(PacketCoordinatorType.PACKET_COORDINATOR_GC_CONNECT_FAILED)
 
@@ -508,6 +522,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_DIRECT_CONNECT(self, protocol_version, token, tracking_number, hostname, port):
         data = write_init(PacketCoordinatorType.PACKET_COORDINATOR_GC_DIRECT_CONNECT)
 
@@ -519,6 +534,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_STUN_REQUEST(self, protocol_version, token):
         data = write_init(PacketCoordinatorType.PACKET_COORDINATOR_GC_STUN_REQUEST)
 
@@ -527,6 +543,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_STUN_CONNECT(
         self, protocol_version, token, tracking_number, interface_number, hostname, port
     ):
@@ -541,6 +558,7 @@ class CoordinatorProtocol(TCPProtocol):
         write_presend(data, SEND_TCP_MTU)
         await self.send_packet(data)
 
+    @tracer.traced("coordinator")
     async def send_PACKET_COORDINATOR_GC_TURN_CONNECT(
         self, protocol_version, token, tracking_number, ticket, connection_string
     ):
