@@ -1,6 +1,7 @@
 import enum
 import logging
 
+from .. import tracer
 from ..wire.exceptions import PacketInvalidData
 from ..wire.read import (
     read_bytes,
@@ -33,7 +34,9 @@ class PacketGameType(enum.IntEnum):
     # TODO -- Packets 0 .. 5 are not implemented yet. Pull Requests are welcome.
     PACKET_SERVER_GAME_INFO = 6
     PACKET_CLIENT_GAME_INFO = 7
-    # TODO -- Packets 8 .. 43 are not implemented yet. Pull Requests are welcome.
+    # TODO -- Packets 8 .. 39 are not implemented yet. Pull Requests are welcome.
+    PACKET_SERVER_SHUTDOWN = 40
+    # TODO -- Packets 41 .. 43 are not implemented yet. Pull Requests are welcome.
     PACKET_END = 44
 
 
@@ -51,6 +54,7 @@ class GameProtocol(TCPProtocol):
     PACKET_END = PacketGameType.PACKET_END
 
     @staticmethod
+    @tracer.traced("game")
     def receive_PACKET_SERVER_GAME_INFO(source, data):
         game_info_version, data = read_uint8(data)
 
@@ -155,6 +159,15 @@ class GameProtocol(TCPProtocol):
             "gamescript_name": gamescript_name,
         }
 
+    @staticmethod
+    @tracer.traced("game")
+    def receive_PACKET_SERVER_SHUTDOWN(source, data):
+        if len(data) != 0:
+            raise PacketInvalidData("more bytes than expected in SERVER_SHUTDOWN; remaining: ", len(data))
+
+        return {}
+
+    @tracer.traced("game")
     async def send_PACKET_CLIENT_GAME_INFO(self):
         data = write_init(PacketGameType.PACKET_CLIENT_GAME_INFO)
         write_presend(data, SEND_TCP_MTU)
